Class: RuboCop::Cop::Rails::Present

Inherits:
Base
  • Object
show all
Extended by:
AutoCorrector
Defined in:
lib/rubocop/cop/rails/present.rb

Overview

This cop checks for code that can be written with simpler conditionals using `Object#present?` defined by Active Support.

Interaction with `Style/UnlessElse`: The configuration of `NotBlank` will not produce an offense in the context of `unless else` if `Style/UnlessElse` is inabled. This is to prevent interference between the auto-correction of the two cops.

Examples:

NotNilAndNotEmpty: true (default)

# Converts usages of `!nil? && !empty?` to `present?`

# bad
!foo.nil? && !foo.empty?

# bad
foo != nil && !foo.empty?

# good
foo.present?

NotBlank: true (default)

# Converts usages of `!blank?` to `present?`

# bad
!foo.blank?

# bad
not foo.blank?

# good
foo.present?

UnlessBlank: true (default)

# Converts usages of `unless blank?` to `if present?`

# bad
something unless foo.blank?

# good
something if foo.present?

Constant Summary collapse

MSG_NOT_BLANK =
'Use `%<prefer>s` instead of `%<current>s`.'
MSG_EXISTS_AND_NOT_EMPTY =
'Use `%<prefer>s` instead of ' \
'`%<current>s`.'
MSG_UNLESS_BLANK =
'Use `if %<prefer>s` instead of ' \
'`%<current>s`.'
RESTRICT_ON_SEND =
%i[!].freeze

Instance Method Summary collapse

Instance Method Details

#autocorrect(corrector, node) ⇒ Object



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/rubocop/cop/rails/present.rb', line 129

def autocorrect(corrector, node)
  method_call, variable1 = unless_blank?(node)

  if method_call
    corrector.replace(node.loc.keyword, 'if')
    range = method_call.loc.expression
  else
    variable1, _variable2 = exists_and_not_empty?(node) || not_blank?(node)
    range = node.loc.expression
  end

  corrector.replace(range, replacement(variable1))
end

#on_and(node) ⇒ Object



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/rubocop/cop/rails/present.rb', line 88

def on_and(node)
  return unless cop_config['NotNilAndNotEmpty']

  exists_and_not_empty?(node) do |var1, var2|
    return unless var1 == var2

    message = format(MSG_EXISTS_AND_NOT_EMPTY, prefer: replacement(var1), current: node.source)

    add_offense(node, message: message) do |corrector|
      autocorrect(corrector, node)
    end
  end
end

#on_if(node) ⇒ Object



114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/rubocop/cop/rails/present.rb', line 114

def on_if(node)
  return unless cop_config['UnlessBlank']
  return unless node.unless?
  return if node.else? && config.for_cop('Style/UnlessElse')['Enabled']

  unless_blank?(node) do |method_call, receiver|
    range = unless_condition(node, method_call)
    msg = format(MSG_UNLESS_BLANK, prefer: replacement(receiver),
                                   current: range.source)
    add_offense(range, message: msg) do |corrector|
      autocorrect(corrector, node)
    end
  end
end

#on_or(node) ⇒ Object



102
103
104
105
106
107
108
109
110
111
112
# File 'lib/rubocop/cop/rails/present.rb', line 102

def on_or(node)
  return unless cop_config['NilOrEmpty']

  exists_and_not_empty?(node) do |var1, var2|
    return unless var1 == var2

    add_offense(node, message: MSG_EXISTS_AND_NOT_EMPTY) do |corrector|
      autocorrect(corrector, node)
    end
  end
end

#on_send(node) ⇒ Object



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/rubocop/cop/rails/present.rb', line 76

def on_send(node)
  return unless cop_config['NotBlank']

  not_blank?(node) do |receiver|
    message = format(MSG_NOT_BLANK, prefer: replacement(receiver), current: node.source)

    add_offense(node, message: message) do |corrector|
      autocorrect(corrector, node)
    end
  end
end