Module: RuboCop::Cop::TargetRailsVersion::InstanceMethods

Defined in:
lib/rubocop/cop/mixin/target_rails_version.rb

Overview

Instance methods for cops that use the resolved target Rails version at runtime, included automatically when a cop extends TargetRailsVersion. On RuboCop < 2.0, #target_rails_version shadows RuboCop::Cop::Base#target_rails_version, so the resolution is owned by rubocop-rails on all supported RuboCop versions.

Instance Method Summary collapse

Instance Method Details

#target_rails_versionObject



58
59
60
# File 'lib/rubocop/cop/mixin/target_rails_version.rb', line 58

def target_rails_version
  @target_rails_version ||= TargetRailsVersion.resolve(config)
end